#!/bin/bash

# Nagios / Icinga script to get the temperatue from TEMPer1 USB sensor
# (http://pcsensor.com/index.php?_a=product&product_id=7)
#
# 2014-07-24, 12:33:20, haasc (christoph@haas-online.org): fixed handling of
# decimal pointed temperature output, changed input program from pcsensor to
# temperv14, code cleanup and partly rewrite
# 2014-08-11, 17:19:42, haasc: 
# option for degrees Celcius or degrees Fahrenheid
				
# original version from http://www.panticz.de/Icinga-plugins / 
# https://raw.githubusercontent.com/panticz/icinga/master/plugins/check_temp
# TODO: fix errors
# USB interrupt read: No such device
# Fatal error> USB read failed


# pre-requisites:
# * /usr/local/sbin/temperv14 from wget http://dev-random.net/wp-content/uploads/2013/08/temperv14.zip
#   for temper1 with lsusb output: ID 0c45:7401 Microdia
#   unzip temperv14.zip, cd into temperv14, make, copy temperv14 executable to /usr/local/sbin
#   (from http://dev-random.net/temperature-measuring-using-linux-and-raspberry-pi/ )
# * put with visudo in /etc/sudoers the following line:
#   nagios ALL = NOPASSWD: /usr/lib/nagios/plugins/check_temper1.sh

# USAGE:
# ./check_temper1.sh <warn> <crit> <f>

DEGREES=c
PROG=/usr/local/sbin/temperv14
WARN=$1
CRIT=$2
OK=0
WARNING=1
CRITICAL=2
UNKNOWN=3

function usage()
{
	echo "*** Usage: ./check_temper1.sh <warn> <crit>"
	echo "    temperature must be in °C with one position after decimal point"
	echo "    e.g. ./check_temper1.sh 24.0 27.3"
	echo " "
	echo "*** Degrees Celcius / Degrees Fahrenheid:"
	echo "    standard: Degrees Celcius"
	echo "    for degrees Fahreheid use third parameter 'f'"
	echo "    ./check_temper1.sh 75,2 81,14 f"
	echo " "
	echo "*** possible outputs:"
	echo "    OK: 23.00°C Temperature is below warn threshold 24.0°C"
	echo "    WARNING: 25.00°C Temperature is above / equals warn threshold 24.0°C"
	echo "    CRITICAL: 28.00°C Temperature is above / equals crit threshold 27.3°C"
	echo "  or with degrees Fahrenheid e.g.:"
	echo "    WARNING: 77.79°F Temperature is above / equals warn threshold 75,2°F"
}

function check_arg()
{
	# make sure you supplied all 2 or 3 arguments
	if [ $# -ne 2 -a $# -ne 3 ] ; then
		usage
		exit $OK
	fi
	if [ $# -eq 3 ]; then
		DEGREES=f
		check_warn_vs_crit
	fi
}

function check_warn_vs_crit()
{
	# make sure CRIT is larger than WARN
	if ( expr $WARN \> $CRIT >/dev/null ); then
		echo "UNKNOWN: WARN value may not be greater than or equal the CRIT value"
		exit $UNKNOWN
	fi
}

function init()
{
	check_arg $*
	check_warn_vs_crit
}

function get_temperature()
{
	# gets temperature and stores it in $HEAT
	# and make sure we get a numeric output
	if [ -x $PROG ];then
		HEAT=`sudo $PROG -$DEGREES`
		case "$HEAT" in
		[0-9]* )
			echo "do nothing" > /dev/null
			;;
		* )
			echo "UNKNOWN: Could not get temperature"
			exit $UNKNOWN
			;;
		esac
	else
		echo "UNKNOWN: cannot execute $PROG"
		exit $UNKNOWN
	fi
}

function check_heat()
{
	# checks temperature and replies according to $CRIT and $WARN
	if ( expr $HEAT \< $WARN >/dev/null ); then
		echo "OK: $HEAT°${DEGREES^^} Temperature is below warn threshold $WARN°${DEGREES^^}"
		exit $OK
	elif ( expr $HEAT \< $CRIT >/dev/null ); then
		echo "WARNING: $HEAT°${DEGREES^^} Temperature is above / equals warn threshold $WARN°${DEGREES^^}"
		exit $WARNING
	elif ( expr $HEAT \> $CRIT >/dev/null ); then
		echo "CRITICAL: $HEAT°${DEGREES^^} Temperature is above / equals crit threshold $CRIT°${DEGREES^^}"
		exit $CRITICAL
	else
		echo "UNKNOWN: Temperature is above UNKNOWN"
		exit $UNKNOWN
	fi
		
}


#
# Main
#

init $*
get_temperature
check_heat

